@@ -1,23 +1,23 @@
 from datetime import datetime
 from typing import Any
-import inspect
 
 
 def is_first_item_equal_to_second_item(first_item: Any, second_item: Any) -> bool:
     """
-    Compare two items and check if they are equal
-    :param first_item: The first item to compare
-    :param second_item: The second item to compare
-    :return: Boolean True or False
+    Compare two items and check if they are equal.
+    :param first_item: The first item to compare.
+    :param second_item: The second item to compare.
+    :return: Boolean True or False.
     """
     return first_item == second_item
 
+
 def is_first_item_less_than_second_item(first_item: Any, second_item: Any) -> bool:
     """
-    Check if first item is less than second item
-    :param first_item: The first item to compare
-    :param second_item: The second item to compare
-    :return: Boolean True or False
+    Check if first item is less than second item.
+    :param first_item: The first item to compare.
+    :param second_item: The second item to compare.
+    :return: Boolean True or False.
     """
     if not isinstance(first_item, int) or not isinstance(first_item, float):
         raise Exception("The first item isn't a number")
@@ -25,12 +25,13 @@ def is_first_item_less_than_second_item(first_item: Any, second_item: Any) -> bo
         raise Exception("The second item isn't a number")
     return first_item < second_item
 
+
 def is_first_item_greater_than_second_item(first_item: Any, second_item: Any) -> bool:
     """
-    Check if first item is greater than second item
-    :param first_item: The first item to compare
-    :param second_item: The second item to compare
-    :return: Boolean True or False
+    Check if first item is greater than second item.
+    :param first_item: The first item to compare.
+    :param second_item: The second item to compare.
+    :return: Boolean True or False.
     """
     if not isinstance(first_item, int) or not isinstance(first_item, float):
         raise Exception("The first item isn't a number")
@@ -38,12 +39,13 @@ def is_first_item_greater_than_second_item(first_item: Any, second_item: Any) ->
         raise Exception("The second item isn't a number")
     return first_item > second_item
 
+
 def is_first_item_less_or_equal_than_second_item(first_item: Any, second_item: Any) -> bool:
     """
-    Check if first item is less or equal to second item
-    :param first_item: The first item to compare
-    :param second_item: The second item to compare
-    :return: Boolean True or False
+    Check if first item is less or equal to second item.
+    :param first_item: The first item to compare.
+    :param second_item: The second item to compare.
+    :return: Boolean True or False.
     """
     if not isinstance(first_item, int) or not isinstance(first_item, float):
         raise Exception("The first item isn't a number")
@@ -51,12 +53,13 @@ def is_first_item_less_or_equal_than_second_item(first_item: Any, second_item: A
         raise Exception("The second item isn't a number")
     return first_item <= second_item
 
+
 def is_first_item_greater_or_equal_than_second_item(first_item: Any, second_item: Any) -> bool:
     """
-    Check if first item is greater or equal to second item
-    :param first_item: The first item to compare
-    :param second_item: The second item to compare
-    :return: Boolean True or False
+    Check if first item is greater or equal to second item.
+    :param first_item: The first item to compare.
+    :param second_item: The second item to compare.
+    :return: Boolean True or False.
     """
     if not isinstance(first_item, int) or not isinstance(first_item, float):
         raise Exception("The first item isn't a number")
@@ -64,13 +67,14 @@ def is_first_item_greater_or_equal_than_second_item(first_item: Any, second_item
         raise Exception("The second item isn't a number")
     return first_item >= second_item
 
+
 def is_time_interval_less_or_equal(datetime1: Any, datetime2: Any, interval_in_seconds: int) -> bool:
     """
     Check if the interval between 2 date-times is less or equal than the given amount of seconds.
-    :param datetime1: The first datetime object
-    :param datetime2: The second datetime object
-    :param interval_in_seconds: The interval in seconds
-    :return: Boolean True or False
+    :param datetime1: The first datetime object.
+    :param datetime2: The second datetime object.
+    :param interval_in_seconds: The interval in seconds.
+    :return: Boolean True or False.
     """
     if not isinstance(datetime1, datetime):
         datetime1 = datetime.combine(datetime1, datetime.now().time())
@@ -78,29 +82,31 @@ def is_time_interval_less_or_equal(datetime1: Any, datetime2: Any, interval_in_s
         datetime2 = datetime.combine(datetime2, datetime.now().time())
     return (datetime2 - datetime1).total_seconds() <= int(interval_in_seconds)
 
+
 def is_time_number_of_seconds_ago(date_time: Any, interval_in_seconds: int) -> bool:
     """
     Check if the interval of a date-time is less or equal than the given amount of seconds compared to now.
-    :param datetime1: The first datetime object
-    :param datetime2: The second datetime object
-    :param interval_in_seconds: The interval in seconds
-    :return: Boolean True or False
+    :param date_time: The datetime object.
+    :param interval_in_seconds: The interval in seconds.
+    :return: Boolean True or False.
     """
     if not isinstance(date_time, datetime):
         date_time = datetime.combine(date_time, datetime.now().time())
     return (date_time - datetime.now()).total_seconds() <= int(interval_in_seconds)
 
+
 def item1_contains_item2(item1: Any, item2: Any, exact_match: bool = True) -> bool:
     """
     Check if item 1 contains item2.
+    :param exact_match:
     :param item1: The first object.
     :param item2: The second object.
-    :return: True or False
+    :return: True or False.
     """
     if isinstance(item1, str) and isinstance(item2, str):
         return str(item1).__contains__(item2)
     if isinstance(item1, dict) and isinstance(item2, str):
-        if exact_match == True:
+        if exact_match:
             return item1.keys().__contains__(item2)
         else:
             for x in item1.keys():
@@ -108,7 +114,7 @@ def item1_contains_item2(item1: Any, item2: Any, exact_match: bool = True) -> bo
                     return True
             return False
     if isinstance(item1, list) and isinstance(item2, str):
-        if exact_match == True:
+        if exact_match:
             return item1.__contains__(item2)
         else:
             for x in item1:
@@ -118,13 +124,26 @@ def item1_contains_item2(item1: Any, item2: Any, exact_match: bool = True) -> bo
     return item1.__contains__(item2)
 
 
-def does_list_contain_item(list_object: list, item:Any) -> bool:
+def does_list_contain_item(list_object: list, item: Any) -> bool:
     """
-    Check if list contains an item
-    :param list_object: The list object
-    :param item: The item to check for
-    :return: True or False
+    Check if list contains an item.
+    :param list_object: The list object.
+    :param item: The item to check for.
+    :return: True or False.
     """
+    return list_object.__contains__(item)
+
+
+def does_list_contain_any_items(list_object: list) -> bool:
+    """
+    Check if a list contains items.
+    :param list_object: The list object to check.
+    :return: True or False.
+    """
+    if list_object is None:
+        return False
+    if not isinstance(list_object, list):
+        list_object = [list_object]
     if len(list_object) > 0:
         tmp = str(list_object[0])
         if tmp.startswith("%") and tmp.endswith("%") and len(list_object) == 1:
@@ -135,33 +154,17 @@ def does_list_contain_item(list_object: list, item:Any) -> bool:
         return False
 
 
-def does_list_contain_any_items(list_object: list) -> bool:
+def is_object_empty(inspected_object: Any) -> bool:
     """
-    Check if a list contains items
-    :param list_object: The list object to check
-    :return: True or False
+    Check if an item is empty.
+    :return: Boolean True or False.
     """
-    if list_object is None:
-        return False
-    if not isinstance(list_object, list):
-        list_object = [list_object]
-    if len(list_object) > 0:
-        return True
-    else:
-        return False
-
-def is_item_empty(item: Any) -> bool:
-    """
-    Check if an item is empty
-    :param item: The item to check
-    :return: Boolean True or False
-    """
-    if isinstance(item, str):
-        return item == ""
-    if isinstance(item, list):
-        return len(item) == 0
-    if isinstance(item, dict):
-        return len(item.keys()) == 0
-    if isinstance(item, object):
-        return item is None
-    raise Exception("Cannot determine if given item is empty...")
+    if isinstance(inspected_object, str):
+        return inspected_object == ""
+    if isinstance(inspected_object, list):
+        return len(inspected_object) == 0
+    if isinstance(inspected_object, dict):
+        return len(inspected_object.keys()) == 0
+    if isinstance(inspected_object, inspected_object):
+        return inspected_object is None
+    raise Exception("Cannot determine if given object is empty...")
